#!/usr/bin/env python3
# -*-coding:utf-8-*-

# ==================================================================================
#  Copyright:
#
#      Copyright (C) 2012 -2017 Konstas Marmatakis <marmako@gmail.com>
#
#   License:
#
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License version 3 as
#      published by the Free Software Foundation.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this package; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# ==================================================================================

__enimerothike__ = '2017-11-14'

PSIFIA = {1: "Ένα",
          2: "Δύο",
          3: "Τρία",
          4: "Τέσσερα",
          5: "Πέντε",
          6: "Έξι",
          7: "Επτά",
          8: "Οκτώ",
          9: "Εννέα"}

DEKADES = {10: "Δέκα",
          11: "Έντεκα",
          12: "Δώδεκα",
          13: "Δεκατρία",
          14: "Δεκατέσσερα",
          15: "Δεκαπέντε",
          16: "Δεκαέξι",
          17: "Δεκαεπτά",
          18: "Δεκαοκτώ",
          19: "Δεκαεννέα"}

EIKOSIENENINTA = {2: "Είκοσι ",
                 3: "Τριάντα ",
                 4: "Σαράντα ",
                 5: "Πενήντα ",
                 6: "Εξήντα ",
                 7: "Εβδομήντα ",
                 8: "Ογδόντα ",
                 9: "Ενενήντα "}

EKATONTADES = {1: "Εκατό ",
              2: "Διακόσια ",
              3: "Τριακόσια ",
              4: "Τετρακόσια ",
              5: "Πεντακόσια ",
              6: "Έξακόσια ",
              7: "Επτακόσια ",
              8: "Οκτακόσια ",
              9: "Εννιακόσια "}


def _metatropi_psifion(psifio, psifia=PSIFIA):
    """
     Converts digits to greek words
    """

    try:
        psifio = int(psifio)
        if psifio in psifia.keys():
            return psifia[psifio]
        else:
            return ""
    except ValueError as err:
        print("Πρέπει να δώσετε ψηφίο 0-9.\nΣφάλμα: {0}".format(err))


def _metatropi_dekadon(dekad, dekades=DEKADES, eikosieneninta=EIKOSIENENINTA):
    """Converts tens to greek words
    """

    apotelesma =''

    if int(dekad) in dekades.keys():
        apotelesma = dekades[int(dekad)]
        return apotelesma
    elif int(str(dekad)[0]) in eikosieneninta.keys():
        apotelesma = eikosieneninta[int(str(dekad)[0])]

    return apotelesma + _metatropi_psifion(int(str(dekad)[1]))


def _metatropi_ekatontadon(arithmos, ekatontades=EKATONTADES):
    """Converts hundrets to greek words
    """
    apotelesma = ''

    try:
        if int(arithmos) == 0:
            exit
    except ValueError as err:
            print('\nΟ αριθμός που δώσατε είναι πολύ μεγάλος για χειρισμό, ή δεν είνσι αριθμός: {0}\n\n'.format(err))
            exit

    arithmos = "000"+ str(arithmos)
    arithmos = arithmos[-3:]

    if arithmos[0] != "0":
        try:
            if int(arithmos[0]) in ekatontades.keys():
                apotelesma = ekatontades[int(arithmos[0])]
        except ValueError as err:
            print('\nΟ αριθμός που δώσατε είναι πολύ μεγάλος για χειρισμό, ή δεν είνσι αριθμός: {0}\n\n'.format(err))
            exit
#            raise ValueError('Ο αριθμός που δώσατε είναι πολύ μεγάλος ή δεν είναι αριθμός.')

    if arithmos[1] != "0":
        apotelesma = apotelesma + _metatropi_dekadon(arithmos[1:])

    else:
        apotelesma = apotelesma + _metatropi_psifion(arithmos[2])

    return apotelesma



#!/home/km/mytestenv/bin/python3

from tkinter import *
from tkinter import ttk

from numtogreek import n2g

root = Tk()
root.title("Numbers")

v = StringVar()
v1 = IntVar()
def convnum(event):
    s = ''
    try:
        if v1.get() == 1:
            
            s = n2g.n2g(ent.get())
            v.set(s.upper())
        elif v1.get() == 2:
            s = n2g.n2g(ent.get())
            v.set(s.lower())
        else:
            s = n2g.n2g(ent.get())
            v.set(s.title())
    except:
        v.set('Δώστε αριθμό!!')
        
lbl = ttk.Label(root, text='Δώστε αριθμό:')
lbl.grid(column=0, row=0)
lbl1 = ttk.Label(root, anchor=E, textvariable=v, wraplength=200)
lbl1.grid(column=0, row=1, columnspan=2)
ent = ttk.Entry(root)
ent.grid(column=1, row=0)
ent.bind('<Return>', convnum)

##ent.insert(0, 'Εδώ γράψτε ακέραιο αριθμό')
lblfrm = ttk.Labelframe(root, relief=RIDGE, labelanchor=SE, text='Πεζά - Κεφαλαία')
lblfrm.grid(column=2, row=0, rowspan=2)
rbutton1 = ttk.Radiobutton(lblfrm, text="ΚΕΦΑΛΑΙΑ", variable=v1, value=1, command=lambda:convnum(0))
rbutton1.grid(column=0, row=0, sticky=W)
v1.set(1)
rbutton2 = ttk.Radiobutton(lblfrm, text="πεζά", variable=v1, value=2, command=lambda:convnum(0))
rbutton2.grid(column=0, row=1, sticky=W)
rbutton3 = ttk.Radiobutton(lblfrm, text="Τίτλος", variable=v1, value=3, command=lambda:convnum(0))
rbutton3.grid(column=0, row=2, sticky=W)

v.set('')
for child in root.winfo_children():
    child.grid_configure(pady=5, padx=5)
ent.focus_set()
root.mainloop()



#!/usr/bin/env python3
#-*-coding:utf-8-*-
import sys

#==================================================================================
#  Copyright:
#
#      Copyright (C) 2012 - 2015 Konstas Marmatakis <marmako@gmail.com>
#
#   License:
#
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License version 3 as
#      published by the Free Software Foundation.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this package; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# ==================================================================================

__enimerothike__ = '30-03-2015'


class NumbersToGreek:
    """
    Converts Numbers to Greek Words.
    """
    def __init__(self, number=0, nomisma=False, onomanomismatos= 'Ευρώ', onomaekatoston='λεπτά', case='lower'):
        self.number = number
        self.nomisma = nomisma
        self.onomanomismatos = onomanomismatos
        self.onomaekatoston = onomaekatoston
        self.case = case

    def convertnumber(self):
        """Converts numbers to greek words
        """

        if self.case not in ('lower', 'upper', 'title'):
            return

        place = {0: " ",
                1: " Χιλιάδες ",
                2: " Εκατομμύρια ",
                3: " Δισεκατομμύρια ",
                4: " Τρισεκατομμύρια ",
                5: " Τετράκις Εκατομμύρια ",
                6: " Πεντάκις Εκατομμύρια ",
                7: " ",
                8: " "}

        replacements = {"Ένα": "Μία",
                      "Τρία": "Τρείς",
                      "Τέσσερα": "Τέσσερις",
                      "Δεκατρία": "Δεκατρείς",
                      "Δεκατέσσερα": "Δεκατέσσερις",
                       "Διακόσια": "Διακόσιες",
                      "Τριακόσια": "Τριακόσιες",
                      "Τετρακόσια": "Τετρακόσιες",
                      "Πεντακόσια": "Πεντακόσιες",
                      "Έξακόσια": "Έξακόσιες",
                      "Επτακόσια": "Επτακόσιες",
                      "Οκτακόσια": "Οκτακόσιες",
                      "Εννιακόσια": "Εννιακόσιες"
                        }

        self.number = str(self.number).strip()
        dekadika = ''
        dol = ''
        decplace = self.number.find(".")
        count = 0

        if decplace >= 0:
            temp = self.number[decplace + 1:]
            if len(temp) > 2:
                temp = temp[:2]
            if len(temp) == 1: # If the number is .6 make it .60
                temp = temp + '0'

            if int(temp[:2]) == 0:
                dekadika = ''
            else:
                dekadika = self.metatropi_dekadon(temp[:2])
            self.number = self.number[:decplace]

        while self.number != "":
            temp = self.metatropi_ekatontadon(self.number[-3:])
            if temp != "":
                if count == 1:
                    for k, v in replacements.items():
                        if k in temp:
                            temp = temp.replace(k, replacements[k])

                dol = temp + place[count] + dol

            if len(self.number) > 3:
                self.number = self.number[:-3]
            else:
                self.number = ""
            count += 1

        if dol == "":
            dol = "Μηδέν"
        elif dol == "Ένα Χιλιάδες ":
            dol = "Χίλια"

        else:
            if dol.startswith("Ένα Χιλιάδες "):
                dol = dol.replace("Ένα Χιλιάδες ", "Χίλια ")
            if dol.find("Ένα Εκατομμύρια") != -1:
                dol = dol.replace( "Ένα Εκατομμύρια", "Ένα εκατομμύριο")
            if dol.find("Ένα Δισεκατομμύρια") != -1:
                dol = dol.replace("Ένα Δισεκατομμύρια", "Ένα Δισεκατομμύριο")
            if dol.find("Ένα Τρισεκατομμύρια") != -1:
                dol = dol.replace("Ένα Τρισεκατομμύρια", "Ένα Τρισεκατομμύριo")
    #         if dol.find("Τρείς Εκατομμύρια") != -1:
    #             dol = dol.raplace("Τρείς Εκατομμύρια", "Τρία εκατομμύρια")
    #         if dol.find("Τέσσερις Εκατομμύρια") != -1:
    #             dol = dol.replace("Τέσσερις Εκατομμύρια", "Τέσσερα Εκατομμύρια")
            if dol.find("Ένα Τετράκις Εκατομμύρια") != -1:
                dol = dol.replace("Ένα Τετράκις Εκατομμύρια", "Ένα Τετράκις Εκατομμύριο")
            if dol.find("Ένα Πεντάκις Εκατομμύρια") != -1:
                dol = dol.replace("Ένα Πεντάκις Εκατομμύρια", "Ένα Πεντάκις Εκατομμύριο")

        if self.nomisma:
            if dekadika == '':
                return dol.strip() + ' ' + self.onomanomismatos
            else:
                return dol.strip() + ' ' + self.onomanomismatos + ' ' + dekadika + ' λεπτά'
        else:
            return dol.strip() + ' ' + dekadika


    def metatropi_ekatontadon(self, arithmos):
        """Converts hundrets to greek words
        """
        apotelesma = ''

        ekatontades = {1: "Έκατό ",
                  2: "Διακόσια ",
                  3: "Τριακόσια ",
                  4: "Τετρακόσια ",
                  5: "Πεντακόσια ",
                  6: "Έξακόσια ",
                  7: "Επτακόσια ",
                  8: "Οκτακόσια ",
                  9: "Εννιακόσια "}

        try:
            if int(arithmos) == 0:
                exit
        except ValueError as err:
            print('\n\nΟ αριθμός που δώσατε είναι πολύ μεγάλος για χειρισμό, ή δεν είνσι αριθμός: {0}\n\n'.format(err))
            sys.exit(128)

        arithmos = "000"+ str(arithmos)
        arithmos = arithmos[-3:]

        if arithmos[0] != "0":
            try:
                if int(arithmos[0]) in ekatontades.keys():
                    apotelesma = ekatontades[int(arithmos[0])]
            except ValueError as err:
                print('\n\nΟ αριθμός που δώσατε είναι πολύ μεγάλος για χειρισμό, ή δεν είνσι αριθμός: {0}\n\n'.format(err))
                sys.exit(128)

        if arithmos[1] != "0":
            apotelesma = apotelesma + self.metatropi_dekadon(arithmos[1:])

        else:
            apotelesma = apotelesma + self.metatropi_psifion(arithmos[2])

        return apotelesma


    def metatropi_dekadon(self, dekad):
        """Converts tens to greek words
        """

        apotelesma =''

        dekades = {10: "Δέκα",
                  11: "Έντεκα",
                  12: "Δώδεκα",
                  13: "Δεκατρία",
                  14: "Δεκατέσσερα",
                  15: "Δεκαπέντε",
                  16: "Δεκαέξι",
                  17: "Δεκαεπτά",
                  18: "Δεκαοκτώ",
                  19: "Δεκαεννέα"}

        eikosieneninta ={2: "Είκοσι ",
                         3: "Τριάντα ",
                         4: "Σαράντα ",
                         5: "Πενήντα ",
                         6: "Εξήντα ",
                         7: "Εβδομήντα ",
                         8: "Ογδόντα ",
                         9: "Ενενήντα "}

        try:
            if int(dekad) in dekades.keys():
                apotelesma = dekades[int(dekad)]
                return apotelesma
            elif int(str(dekad)[0]) in eikosieneninta.keys():
                apotelesma = eikosieneninta[int(str(dekad)[0])]
            else:
                apotelesma = ''
        except ValueError as err:
            print('\n\nΟ αριθμός που δώσατε είναι πολύ μεγάλος για χειρισμό, ή δεν είνσι αριθμός: {0}\n\n'.format(err))
            sys.exit(128)

        return apotelesma + self.metatropi_psifion(int(str(dekad)[1]))

    def metatropi_psifion(self, psifio):
        """
         Converts digits to greek words
        """
        psifia = {1: "Ένα",
                  2: "Δύο",
                  3: "Τρία",
                  4: "Τέσσερα",
                  5: "Πέντε",
                  6: "Έξι",
                  7: "Επτά",
                  8: "Οκτώ",
                  9: "Εννέα"
                  }

        try:
            psifio = int(psifio)
            if psifio in psifia.keys():
                return psifia[psifio]
            else:
                return ""
        except ValueError as err:
            print("Πρέπει να δώσετε ψηφίο 0-9. Δώσατε: {1}\nΣφάλμα: {0}".format(err, psifio))

if __name__ == '__main__':
    n = NumbersToGreek(1963.03, True)
    print(n.convertnumber())
    for i in range(7900, 8002):
        print(i, NumbersToGreek(i, True).convertnumber())

    for i in range(7900, 8002):
        print(i, NumbersToGreek(i, False, case='upper').convertnumber())

    print(NumbersToGreek(21000.01).convertnumber())
    print(NumbersToGreek(21000.01, True).convertnumber())
    print(NumbersToGreek(999999999999999999999.09).convertnumber())



#!/usr/bin/env python3

# ==================================================================================
#  Copyright:
#
#      Copyright (C) 2012 - 2019 Konstas Marmatakis <marmako@gmail.com>
#
#   License:
#
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License version 2 as
#      published by the Free Software Foundati2019on.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this package; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# ==================================================================================
from . import numtogreek
__all__ = ["numtogreek"]

__version__ = "1.0.3"

__doc__ = """Converts numbers to greek words.

    USAGE: n2g(thenumber) or
           n2g(thenumber, currency) or
           n2g(thenumber, currency, case) or
           n2g(thenumber, currency=True, case='lower').

    PARAMETERS:
           thenumber: Integer or Float.
           currency:   True or False. Displays Ευρώ. Default: False.
           case:      String 'title', 'lower', 'capfirst' or 'upper'. Displays the string as Title Case, lower case, Upper the first letter or UPPER CASE.
                      Default 'title'.
onverts numbers to greek words.

    USAGE: n2g(thenumber) or
           n2g(thenumber, currency) or
           n2g(thenumber, currency, case) or
           n2g(thenumber, currency=True, case='lower').

    PARAMETERS:
           thenumber: Integer or Float.
           currency:   True or False. Displays Ευρώ. Default: False.
           case:      String 'title', 'lower', 'capfirst' or 'upper'. Displays the string as Title Case, lower case, Capitalized first letter or UPPER CASE.
                      Default 'title'.
"""


def n2g(thenumber, currency=False, case='title'):
    """Converts numbers to greek words.

    USAGE: n2g(thenumber) or
           n2g(thenumber, currency) or
           n2g(thenumber, currency, case) or
           n2g(thenumber, currency=True, case='lower').

    PARAMETERS:
           thenumber: Integer or Float.
           currency:   True or False. Displays Ευρώ. Default: False.
           case:      String 'title', 'lower', 'capfirst' or 'upper'. Displays the string as Title Case, lower case, Upper the first letter or UPPER CASE.
                      Default 'title'.

    >>> n2g(129.929)
    'Εκατό Είκοσι Εννέα και Ενενήντα Δύο'
    >>> n2g(1000000000000000)
    'Ένα Τετράκις Εκατομμύριο'
    >>> n2g(999999999999999)
    'Εννιακόσια Ενενήντα Εννέα Τρισεκατομμύρια Εννιακόσια Ενενήντα Εννέα Δισεκατομμύρια Εννιακόσια Ενενήντα Εννέα Εκατομμύρια Εννιακόσιες Ενενήντα Εννέα Χιλιάδες Εννιακόσια Ενενήντα Εννέα'
    >>> n2g(333333.33)
    'Τριακόσιες Τριάντα Τρείς Χιλιάδες Τριακόσια Τριάντα Τρία και Τριάντα Τρία'
    >>> n2g(333333.33, True, 'lower')
    'τριακόσιες τριάντα τρείς χιλιάδες τριακόσια τριάντα τρία ευρώ  και τριάντα τρία λεπτά'
    >>> n2g(333333.00, True, 'upper')
    'ΤΡΙΑΚΌΣΙΕΣ ΤΡΙΆΝΤΑ ΤΡΕΊΣ ΧΙΛΙΆΔΕΣ ΤΡΙΑΚΌΣΙΑ ΤΡΙΆΝΤΑ ΤΡΊΑ ΕΥΡΏ'
    >>>
    """

    case = case.lower()

    if case not in ('lower', 'upper', 'title', 'capfirst'):
        print("Το όρισμα «{0}», που δώσατε, δεν είναι έγκυρο.".format(case))
        return

    place = {0: " ",
            1: " Χιλιάδες ",
            2: " Εκατομμύρια ",
            3: " Δισεκατομμύρια ",
            4: " Τρισεκατομμύρια ",
            5: " Τετράκις Εκατομμύρια ",
            6: " Πεντάκις Εκατομμύρια ",
            7: " Εξάκις Εκατομμυρια ",
            8: " Έπτάκις Εκατομμύρια ",
            9: " Οκτάκις Εκατομμύρια "}

    replacements = {"Ένα": "Μία",
                  "Τρία": "Τρείς",
                  "Τέσσερα": "Τέσσερις",
                  "Δεκατρία": "Δεκατρείς",
                  "Δεκατέσσερα": "Δεκατέσσερις",
                   "Διακόσια": "Διακόσιες",
                  "Τριακόσια": "Τριακόσιες",
                  "Τετρακόσια": "Τετρακόσιες",
                  "Πεντακόσια": "Πεντακόσιες",
                  "Έξακόσια": "Έξακόσιες",
                  "Επτακόσια": "Επτακόσιες",
                  "Οκτακόσια": "Οκτακόσιες",
                  "Εννιακόσια": "Εννιακόσιες"
                    }

    thenumber = str(thenumber).strip()
    dekadika = ''
    dol = ''
    decplace = thenumber.find(".")
    count = 0

    if decplace >= 0:
        temp = thenumber[decplace + 1:]
        if len(temp) > 2:
            temp = temp[:2]
        if len(temp) == 1:  # If the number is .6 make it .60
            temp = temp + '0'

        if int(temp[:2]) == 0:
            dekadika = ''
        else:
            dekadika = numtogreek._metatropi_dekadon(temp[:2])
        thenumber = thenumber[:decplace]

    while thenumber != "":
        temp = numtogreek._metatropi_ekatontadon(thenumber[-3:])
        if temp != "":
            if count == 1:
                for k, v in replacements.items():
                    if k in temp:
                        temp = temp.replace(k, v)
            try:
                dol = temp + place[count] + dol
            except KeyError as err:
                print('\nΟ αριθμός που δώσατε είναι πολύ μεγάλος για χειρισμό: {0}\n\n'.format(err))
                return
                # exit #raise

        if len(thenumber) > 3:
            thenumber = thenumber[:-3]
        else:
            thenumber = ""
        count += 1

    if dol == "":
        dol = "Μηδέν"
    elif dol == "Ένα Χιλιάδες ":
        dol = "Χίλια"

    else:
        if dol.startswith("Ένα Χιλιάδες "):
            dol = dol.replace("Ένα Χιλιάδες ", "Χίλια ")
        if dol.startswith("Μία Χιλιάδες "):
            dol = dol.replace("Μία Χιλιάδες ", "Χίλια ")
        if dol.find("Ένα Εκατομμύρια") != -1:
            dol = dol.replace("Ένα Εκατομμύρια", "Ένα εκατομμύριο")
        if dol.find("Ένα Δισεκατομμύρια") != -1:
            dol = dol.replace("Ένα Δισεκατομμύρια", "Ένα Δισεκατομμύριο")
        if dol.find("Ένα Τρισεκατομμύρια") != -1:
            dol = dol.replace("Ένα Τρισεκατομμύρια", "Ένα Τρισεκατομμύριo")
        if dol.find("Ένα Τετράκις Εκατομμύρια") != -1:
            dol = dol.replace("Ένα Τετράκις Εκατομμύρια", "Ένα Τετράκις Εκατομμύριο")
        if dol.find("Ένα Πεντάκις Εκατομμύρια") != -1:
            dol = dol.replace("Ένα Πεντάκις Εκατομμύρια", "Ένα Πεντάκις Εκατομμύριο")

    if dekadika == '':
        dekadika = ' '
    else:
        if dekadika == "Ένα":
            dekadika = " και Ένα"
        else:
            dekadika = " και {0}".format(dekadika)
    if currency:
        if dekadika == '' or dekadika == ' ' or dekadika is None:
            greekword = "{0} Ευρώ".format(dol.strip())
        else:
            if dekadika == " και Ένα":
                greekword = "{0} Ευρώ {1} Λεπτό".format(dol.strip(), dekadika.strip())
            else:
                greekword = "{0} Ευρώ {1} Λεπτά".format(dol.strip(), dekadika.strip())
    else:
        greekword = dol.strip() + dekadika

    if case == 'lower':
        return greekword.lower().strip()
    elif case == 'upper':
        return greekword.upper().strip()
    elif case == 'capfirst':
        return greekword.capitalize().strip()
    else:
        return greekword.strip()



#!/usr/bin/env python3

#==================================================================================
#  Copyright:
#
#      Copyright (C) 2012 - 2019 Konstas Marmatakis <marmako@gmail.com>
#
#   License:
#
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License version 3 as
#      published by the Free Software Foundation.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this package; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#==================================================================================

import sys
from setuptools import setup

files = ['data/*']

if (sys.version_info.major, sys.version_info.minor) < (3, 3):
    print("You must have version 3.3 and above. Recommended Version: 3.4.")
    sys.exit(1)

setup(name='numtogreek',
      version=open('numtogreek/data/VERSION', encoding='utf-8').read().strip(),
      description='Converts Numbers (Integers and Floats) to Greek Words.',
      author='Konstas Marmatakis',
      author_email='marmako@gmail.com',
      maintainer='kamar',
      url='https://bitbucket.org/kamar/numtogreek',
      keywords='numbers, convert, greek, words, convert number, greek words',
      license='GNU General Public License v3 (GPLv3)',
      packages=['numtogreek'],
      package_data={'numtogreek': files},
      long_description =open('numtogreek/data/README.rst', encoding='utf-8').read().strip(),
      platforms=['Linux', 'Windows'],
      classifiers=[
                   'Development Status :: 5 - Production/Stable',
                   'Environment :: Console',
                   'Intended Audience :: Other Audience',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
                   'Natural Language :: Greek',
                   'Operating System :: Microsoft',
                   'Operating System :: Microsoft :: Windows :: Windows 7',
                   'Operating System :: Microsoft :: Windows :: Windows 8',
                   'Operating System :: Microsoft :: Windows :: Windows 8.1',
                   'Operating System :: POSIX',
                   'Operating System :: POSIX :: Linux',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.3',
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6'])
